@@ -2,7 +2,7 @@
 
 """
 Copyright (c) 2006-2017 sqlmap developers (http://sqlmap.org/)
-See the file 'doc/COPYING' for copying permission
+See the file 'LICENSE' for copying permission
 """
 
 import re
@@ -94,7 +94,7 @@ class Fingerprint(GenericFingerprint):
 
         if wasLastResponseDBMSError():
             threadData = getCurrentThreadData()
-            match = re.search("Could not find file\s+'([^']+?)'", threadData.lastErrorPage[1])
+            match = re.search(r"Could not find file\s+'([^']+?)'", threadData.lastErrorPage[1])
 
             if match:
                 retVal = match.group(1).rstrip("%s.mdb" % randStr)
@@ -130,7 +130,7 @@ class Fingerprint(GenericFingerprint):
         if kb.bannerFp:
             banVer = kb.bannerFp["dbmsVersion"]
 
-            if re.search("-log$", kb.data.banner):
+            if re.search(r"-log$", kb.data.banner):
                 banVer += ", logging enabled"
 
             banVer = Format.getDbms([banVer])
@@ -146,7 +146,7 @@ class Fingerprint(GenericFingerprint):
         return value
 
     def checkDbms(self):
-        if not conf.extensiveFp and (Backend.isDbmsWithin(ACCESS_ALIASES) or (conf.dbms or "").lower() in ACCESS_ALIASES):
+        if not conf.extensiveFp and Backend.isDbmsWithin(ACCESS_ALIASES):
             setDbms(DBMS.ACCESS)
 
             return True
